﻿using System.Globalization;
using System.Windows.Controls;
using System.Windows.Data;

namespace TestProject
{
    /// <summary>
    /// 바인딩 그룹 검증 규칙
    /// </summary>
    public class BindingGroupValidationRule : ValidationRule
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 검증하기 - Validate(value, cultureInfo)

        /// <summary>
        /// 검증하기
        /// </summary>
        /// <param name="value">값</param>
        /// <param name="cultureInfo">문화 정보</param>
        /// <returns>검증 결과</returns>
        public override ValidationResult Validate(object value, CultureInfo cultureInfo)
        {
            BindingGroup bindingGroup = value as BindingGroup;

            DataItem1 dataItem1 = null;
            DataItem2 dataItem2 = null;

            foreach(object item in bindingGroup.Items)
            {
                if(item is DataItem1)
                {
                    dataItem1 = item as DataItem1;
                }

                if(item is DataItem2)
                {
                    dataItem2 = item as DataItem2;
                }
            }

            if(dataItem1 == null || dataItem2 == null)
            {
                return new ValidationResult(false, "소스 객체에서 바인딩 그룹을 찾을 수 없습니다.");
            }

            string value1 = bindingGroup.GetValue(dataItem1, "Value") as string;
            string value2 = bindingGroup.GetValue(dataItem2, "Value") as string;

            if(value1 != value2)
            {
                return new ValidationResult(false, "두 문자열이 동일해야 합니다.");
            }

            return ValidationResult.ValidResult;
        }

        #endregion
    }
}